@@ -120,6 +120,9 @@ class TestMetadataAgent(base.TestOVNFunctionalBase):
                 check_error=True)
             self.assertEqual(external_ids[ovn_const.OVN_AGENT_OVN_BRIDGE],
                              self.OVN_BRIDGE)
+            self.assertEqual(
+                external_ids[ovn_const.OVN_AGENT_METADATA_SB_CFG_KEY],
+                '0')
 
         # Metadata agent will open connections to OVS and SB databases.
         # Close connections to them when the test ends,
@@ -129,16 +132,6 @@ class TestMetadataAgent(base.TestOVNFunctionalBase):
         return agt
 
     def test_metadata_agent_healthcheck(self):
-        chassis_row = self.sb_api.db_find(
-            AGENT_CHASSIS_TABLE,
-            ('name', '=', self.chassis_name)).execute(
-            check_error=True)[0]
-
-        # Assert that, prior to creating a resource the metadata agent
-        # didn't populate the external_ids from the Chassis
-        self.assertNotIn(ovn_const.OVN_AGENT_METADATA_SB_CFG_KEY,
-                         chassis_row['external_ids'])
-
         # Let's list the agents to force the nb_cfg to be bumped on NB
         # db, which will automatically increment the nb_cfg counter on
         # NB_Global and make ovn-controller copy it over to SB_Global. Upon
@@ -366,10 +359,8 @@ class TestMetadataAgent(base.TestOVNFunctionalBase):
         # disable DHCP on the subnet where the metadata's port is located.
         lswitch_name = 'ovn-' + uuidutils.generate_uuid()
         mdt_port_name = 'ovn-mdt-' + uuidutils.generate_uuid()
-        mac_ip = 'AA:AA:AA:AA:AA:AA 192.168.122.123'
 
-        mdt_pb_event = events.WaitForUpdatePortBindingEvent(
-            mdt_port_name, mac=[mac_ip])
+        mdt_pb_event = events.WaitForCreatePortBindingEvent(mdt_port_name)
         self.handler.watch_event(mdt_pb_event)
 
         with self.nb_api.transaction(
@@ -378,9 +369,10 @@ class TestMetadataAgent(base.TestOVNFunctionalBase):
                 self.nb_api.ls_add(lswitch_name))
             self._create_metadata_port(txn, lswitch_name, mdt_port_name)
 
-        external_ids = {ovn_const.OVN_CIDRS_EXT_ID_KEY: ""}
-        self.nb_api.set_lswitch_port(lport_name=mdt_port_name,
-                                     external_ids=external_ids).execute()
+            external_ids = {ovn_const.OVN_CIDRS_EXT_ID_KEY: ""}
+            txn.add(
+                self.nb_api.set_lswitch_port(lport_name=mdt_port_name,
+                                             external_ids=external_ids))
 
         self.assertTrue(mdt_pb_event.wait())
 
